@@ -535,17 +535,39 @@ class Group(Base):
 
 class GroupStudent(Base):
     """
-    Модель "Студент в группе"
+    Студент в группе
     """
-
     __tablename__ = 'univer_group_student'
 
+    # Идентификатор
     id = Column('group_student_id', Integer, primary_key=True)
+
+    # Группа
     group_id = Column(ForeignKey('univer_group.group_id'))
     group = relationship('Group', backref='group_students')
+
+    # Студент
     student_id = Column(ForeignKey('univer_students.students_id'))
     student = relationship('Student')
 
+    # Дата и время выбора группы студентом
+    choice_date = Column('student_choice_date', DateTime)
+
+    # Идентификатор старого выбора группы студентом
+    old_choice_id = Column('old_student_choice_id', Integer)
+
+    # Студент зарегистрирован (Студент самостоятельно выбрал группу?)
+    student_reg = Column(Boolean)
+
+    # Неизвестное поле
+    retake_type = Column(Integer)
+
+    def __repr__(self):
+        return f'<GroupStudent {self} (id={self.id} group={self.group_id} student={self.student_id})>'
+
+    def __str__(self):
+        return f'{self.group}: {self.student}'
+
 
 class Controll(Base):
     """
